@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2000 QUALCOMM Incorporated. All rights reserved.
+ * Copyright (c) 2008 QUALCOMM Incorporated. All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  */
@@ -8,6 +8,9 @@
 /*
  * Revisions:
  *
+ * 02/09/01  [rg]
+ *         - Include year.
+ *
  * 08/19/00  [rg]
  *         - Added vlogit.
  *
@@ -139,6 +142,10 @@ vlogit ( FILE        *str,       /* STREAM to write to, or NULL for syslog */
     struct timeval   tval;
     size_t           iLeft     = 0;
     int              iChunk    = 0;
+    int              iDateLen  = 0;
+    long             lMsec     = 0;
+    char            *pDate     = NULL;
+    char            *pYear     = NULL;
 
 
     /* 
@@ -155,7 +162,7 @@ vlogit ( FILE        *str,       /* STREAM to write to, or NULL for syslog */
         int  len;
         
         iLeft -= ( iChunk >= 0 ? iChunk : strlen(msgbuf) );
-        len    = Qsprintf ( whence, " [%s:%d]", fn, ln );
+        len    = Qsprintf ( whence, " [%s:%lu]", fn, ln );
         strncat ( msgbuf, whence, iLeft );
         msgbuf [ sizeof(msgbuf) -1 ] = '\0'; /* just to make sure */
         iLeft -= len;
@@ -170,13 +177,14 @@ vlogit ( FILE        *str,       /* STREAM to write to, or NULL for syslog */
             tval.tv_usec = 0;
         }
         date_time = ctime ( (time_t *) &tval.tv_sec );
-        date_time [ strlen(date_time) - 6 ] = '\0'; /* cut off the year */
-        sprintf ( date_time + strlen(date_time), ".%03ld",
-                  (tval.tv_usec + 500) / 1000 );
-        fprintf ( str, "%s [%ld] %s\n", 
-                      date_time + 4, /* skip day of week name */
-                      (long) getpid(), msgbuf );
-        fprintf ( str, "%s \n", date_time + 4 );
+        pDate     = date_time + 4; /* skip day of week name */
+        iDateLen  = strlen ( pDate ); /* length including year */
+        pYear     = pDate + ( iDateLen - 5 ); /* point to start of year */
+        date_time [ iDateLen - 2 ] = '\0'; /* cut off the year */
+        lMsec     = (tval.tv_usec + 500) / 1000; /* convert useconds to milliseconds */
+        fprintf ( str, "%s.%03ld %.4s [%ld] %s\n", 
+                  pDate, lMsec, pYear, (long) getpid(), msgbuf );
+        fprintf ( str, "%s.%03ld %.4s \n", pDate, lMsec, pYear );
         fflush  ( str );
     }
     else {
