@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2008 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  *
@@ -115,7 +115,7 @@ char        *   buf;        /*  Pointer to a message containing
                 } else
                     return ( 0 );
             }
-        }
+        } /* first parameter (command name) */
         else {
             /*
              * Search in the Mdef Array for the presence of this arg.
@@ -126,6 +126,9 @@ char        *   buf;        /*  Pointer to a message containing
 
             for( j = 0; j <= last_index; j++ ) {
                 if ( strcasecmp(mdrArr[j].mdef_macro, p->pop_parm[i]) == 0 ) {
+                    DEBUG_LOG4 ( p, "Parameter %i matched macro %i: %.50s (%.50s)",
+                                 i, j, mdrArr[j].mdef_macro,
+                                 mdrArr[j].mdef_value );
                     p->pop_parm[i] = mdrArr[j].mdef_value;
                     break;
                 }
