@@ -1,10 +1,15 @@
 /*
- * Copyright (c) 2001 QUALCOMM Incorporated. All rights reserved.
+ * Copyright (c) 2008 QUALCOMM Incorporated. All rights reserved.
  * See License.txt file for terms and conditions for modification and
  * redistribution.
  *
  * Revisions:
  *
+ * 12/03/04  [rcg]
+ *         - Applied patch by Helge Oldach to fix bug where X-UIDL
+ *           header was always written, even when Update_status_hdrs
+ *           was false.
+ *
  * 01/31/01  [rcg]
  *         -  No longer hiding messages deleted in prior aborted session
  *           when '--disable-update-abort' set.
@@ -531,11 +536,13 @@ POP     *   p;
             if ( fputs ( buffer, md ) == EOF )
                 break;
 
-            sprintf ( buffer, "X-UIDL: %s", mp->uidl_str );
-            if ( fputs ( buffer, md ) == EOF )
-                break;
-            length += strlen ( buffer ) + 1; /* for CRLF */
-            lines  ++;
+            if ( p->bUpdate_status_hdrs ) {
+                sprintf ( buffer, "X-UIDL: %s", mp->uidl_str );
+                if ( fputs ( buffer, md ) == EOF )
+                    break;
+                length += strlen ( buffer ) + 1; /* for CRLF */
+                lines  ++;
+            }
 
             for ( status_written = 0, inheader = 1;
                   fgets ( buffer, MAXMSGLINELEN, p->drop );
